@@ -41,9 +41,6 @@
 #'   `language` type.
 #' @param effsize.text A character that specifies the relevant effect size.
 #' @param prior.type The type of prior.
-#' @param conf.method The type of index used for Credible Interval. Can be
-#'   `"hdi"` (default), `"eti"`, or `"si"` (see `si()`, `hdi()`, `eti()`
-#'   functions from `bayestestR` package).
 #' @param k Number of digits after decimal point (should be an integer)
 #'   (Default: `k = 2L`).
 #' @param ... Currently ignored.
@@ -88,24 +85,19 @@ add_expression_col <- function(data,
                                  list(quote(italic("n")["pairs"])),
                                  list(quote(italic("n")["obs"]))
                                ),
-                               conf.method = "HDI",
                                k = 2L,
                                k.df = 0L,
                                k.df.error = k.df,
                                ...) {
+  # make sure these columns are present
+  if (!"n.obs" %in% colnames(data)) data %<>% mutate(n.obs = n)
+  if (!"effectsize" %in% colnames(data)) data %<>% mutate(effectsize = method)
 
-  # initial cleanup
-  data %<>%
-    rename_all(.funs = recode, "bayes.factor" = "bf10") %>%
-    mutate(
-      effectsize = ifelse("effectsize" %in% names(.), effectsize, method),
-      n.obs = n
-    )
+  # is this a Bayesian test?
+  data %<>% rename_all(.funs = recode, "bayes.factor" = "bf10")
+  bayesian <- ifelse("bf10" %in% colnames(data), TRUE, FALSE)
 
-  # is this Bayesian test?
-  bayesian <- ifelse("bf10" %in% names(data), TRUE, FALSE)
-
-  # special case for Bayesian analysis
+  # special case for Bayesian contingency table analysis
   if (bayesian && grepl("contingency", data$method[[1]])) data %<>% mutate(effectsize = "Cramers_v")
 
   # convert needed columns to character type
@@ -116,8 +108,7 @@ add_expression_col <- function(data,
     statistic.text     = statistic.text %||% stat_text_switch(method),
     es.text            = effsize.text %||% estimate_type_switch(effectsize),
     prior.distribution = prior_switch(method),
-    conf.method        = toupper(conf.method),
-    n.obs              = .prettyNum(n)
+    n.obs              = .prettyNum(n.obs)
   )
 
   # how many parameters?
