@@ -9,6 +9,7 @@
 #' @export
 tidy_model_parameters <- function(model, ...) {
   stats_df <- model_parameters(model, verbose = FALSE, ...) %>%
+    mutate(conf.method = . %@% "ci_method") %>%
     select(where(~ !all(is.na(.x))), -matches("Difference")) %>% # remove columns where all rows are NAs
     standardize_names(style = "broom") %>%
     rename_all(~ gsub("cramers.", "", .x)) %>%
@@ -25,8 +26,7 @@ tidy_model_parameters <- function(model, ...) {
       as_tibble(.) %>%
       standardize_names(style = "broom") %>%
       rename("estimate" = "r.squared") %>%
-      filter(if_any(matches("component"), ~ (.x == "conditional"))) %>%
-      mutate(effectsize = "Bayesian R-squared")
+      filter(if_any(matches("component"), ~ (.x == "conditional")))
 
     # remove estimates and CIs and use R2 dataframe instead
     stats_df %<>%
