@@ -50,10 +50,6 @@ zeallot::`%->%`
 
 # easystats -------------------------------------
 
-#' @export
-#' @importFrom correlation correlation
-correlation::correlation
-
 #' @export
 #' @importFrom insight format_value
 insight::format_value
