@@ -1,9 +1,8 @@
-# long_to_wide_converter works ---------------------------------------------
+withr::local_options(list(tibble.width = Inf))
 
 test_that(
   desc = "long_to_wide_converter works - spread true",
   code = {
-
     # data without NAs ------------------------------
 
     # within-subjects
@@ -45,7 +44,8 @@ test_that(
 
     # checking datasets
     set.seed(123)
-    expect_snapshot(list(df1, df2, df3, df4))
+    expect_snapshot(purrr::walk(list(df1, df2, df3, df4), dplyr::glimpse))
+    expect_snapshot(purrr::map(list(df1, df2, df3, df4), summary))
   }
 )
 
@@ -53,7 +53,6 @@ test_that(
 test_that(
   desc = "long_to_wide_converter works - spread false",
   code = {
-
     # ----------------------- data without NAs ------------------------------
 
     # within-subjects
@@ -99,7 +98,8 @@ test_that(
 
     # checking datasets
     set.seed(123)
-    expect_snapshot(list(df1, df2, df3, df4))
+    expect_snapshot(purrr::walk(list(df1, df2, df3, df4), dplyr::glimpse))
+    expect_snapshot(purrr::map(list(df1, df2, df3, df4), summary))
   }
 )
 
