@@ -1,3 +1,5 @@
+withr::local_options(list(tibble.width = Inf))
+
 test_that(
   desc = "bayesian (independent samples t-test)",
   code = {
@@ -18,14 +20,13 @@ test_that(
       )
 
     # call
-    expect_snapshot(df$expression)
+    expect_snapshot(df[["expression"]])
   }
 )
 
 test_that(
   desc = "bayesian (paired t-test)",
   code = {
-
     # Bayes factor (paired t-test) ---------------------------------------------
 
     # data
@@ -64,14 +65,13 @@ test_that(
       )
 
     # call
-    expect_snapshot(df$expression)
+    expect_snapshot(df[["expression"]])
   }
 )
 
 test_that(
   desc = "works with subject id",
   code = {
-
     # works with subject id -----------------------------------------------
 
     # data
