@@ -1,10 +1,10 @@
+withr::local_options(list(tibble.width = Inf))
+
 # within-subjects ------------------------------------------------------------
 
 test_that(
   desc = "t_robust - within-subjects - without NAs",
   code = {
-    options(tibble.width = Inf)
-
     # subtitle
     set.seed(123)
     df1 <- two_sample_test(
@@ -19,10 +19,9 @@ test_that(
       k = 4
     )
 
-
     set.seed(123)
     expect_snapshot(select(df1, -expression))
-    expect_snapshot(df1$expression)
+    expect_snapshot(df1[["expression"]])
   }
 )
 
@@ -40,10 +39,9 @@ test_that(
       k = 3L
     )
 
-
     set.seed(123)
     expect_snapshot(select(df1, -expression))
-    expect_snapshot(df1$expression)
+    expect_snapshot(df1[["expression"]])
   }
 )
 
@@ -65,17 +63,15 @@ test_that(
       k = 3
     )
 
-
     set.seed(123)
     expect_snapshot(select(df1, -expression))
-    expect_snapshot(df1$expression)
+    expect_snapshot(df1[["expression"]])
   }
 )
 
 test_that(
   desc = "t_robust - between-subjects - with NAs",
   code = {
-    # subtitle
     set.seed(123)
     df1 <- two_sample_test(
       type = "r",
@@ -87,10 +83,9 @@ test_that(
       k = 4
     )
 
-
     set.seed(123)
     expect_snapshot(select(df1, -expression))
-    expect_snapshot(df1$expression)
+    expect_snapshot(df1[["expression"]])
   }
 )
 
